changeset 754:7494d15503ab draft

New tests added into BitBltUsingBgColor.
author Pavel Tisnovsky <ptisnovs@redhat.com>
date Tue, 01 Sep 2015 11:24:08 +0200
parents 03a29500ef5b
children 73320fa3a318
files ChangeLog src/org/gfxtest/testsuites/BitBltUsingBgColor.java
diffstat 2 files changed, 72 insertions(+), 67 deletions(-) [+]
line wrap: on
line diff
--- a/ChangeLog	Tue Aug 18 13:49:29 2015 +0200
+++ b/ChangeLog	Tue Sep 01 11:24:08 2015 +0200
@@ -1,3 +1,8 @@
+2015-09-01  Pavel Tisnovsky  <ptisnovs@redhat.com>
+
+	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
+	New tests added into BitBltUsingBgColor.
+
 2015-08-18  Pavel Tisnovsky  <ptisnovs@redhat.com>
 
 	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
--- a/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Tue Aug 18 13:49:29 2015 +0200
+++ b/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Tue Sep 01 11:24:08 2015 +0200
@@ -10486,7 +10486,7 @@
     }
 
     /**
      * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_Pre.
      * Background color is set to Color.green.
      *
      * @param image
@@ -10495,13 +10495,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageType4ByteABGR_Pre_backgroundGreen(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.green);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_Pre.
+    public TestResult testBitBltCheckerBufferedImageTypeByteGrayBackgroundGreen(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, Color.green);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      * Background color is set to Color.cyan.
      *
      * @param image
@@ -10510,13 +10510,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageType4ByteABGR_Pre_backgroundCyan(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.cyan);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_Pre.
+    public TestResult testBitBltCheckerBufferedImageTypeByteGrayBackgroundCyan(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, Color.cyan);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      * Background color is set to Color.red.
      *
      * @param image
@@ -10525,13 +10525,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageType4ByteABGR_Pre_backgroundRed(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.red);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_Pre.
+    public TestResult testBitBltCheckerBufferedImageTypeByteGrayBackgroundRed(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, Color.red);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      * Background color is set to Color.magenta.
      *
      * @param image
@@ -10540,13 +10540,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageType4ByteABGR_Pre_backgroundMagenta(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.magenta);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_Pre.
+    public TestResult testBitBltCheckerBufferedImageTypeByteGrayBackgroundMagenta(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, Color.magenta);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      * Background color is set to Color.yellow.
      *
      * @param image
@@ -10555,13 +10555,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageType4ByteABGR_Pre_backgroundYellow(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.yellow);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_Pre.
+    public TestResult testBitBltCheckerBufferedImageTypeByteGrayBackgroundYellow(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, Color.yellow);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      * Background color is set to Color.white.
      *
      * @param image
@@ -10570,13 +10570,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageType4ByteABGR_Pre_backgroundWhite(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.white);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
+    public TestResult testBitBltCheckerBufferedImageTypeByteGrayBackgroundWhite(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, Color.white);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
      * Background color is set to Color.black.
      *
      * @param image
@@ -10585,13 +10585,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeIntBGRbackgroundBlack(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.black);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
+    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedBackgroundBlack(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.black);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
      * Background color is set to Color.blue.
      *
      * @param image
@@ -10600,13 +10600,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeIntBGRbackgroundBlue(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.blue);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
+    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedBackgroundBlue(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.blue);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
      * Background color is set to Color.green.
      *
      * @param image
@@ -10615,13 +10615,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeIntBGRbackgroundGreen(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.green);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
+    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedBackgroundGreen(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.green);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
      * Background color is set to Color.cyan.
      *
      * @param image
@@ -10630,9 +10630,9 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeIntBGRbackgroundCyan(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.cyan);
+    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedBackgroundCyan(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.cyan);
     }
 
     /**
@@ -10486,7 +10486,7 @@
 
     /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_Pre.
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      * Background color is set to Color.green.
      *